@@ -226,6 +226,7 @@ get_scores.instrumental_forest <- function(forest,
 #'               estimate the ATE. WARNING: For valid statistical performance,
 #'               the subset should be defined only using features Xi, not using
 #'               the treatment Wi or the outcome Yi.
+#' @param drop If TRUE, coerce the result to the lowest possible dimension. Default is FALSE.
 #' @param ... Additional arguments (currently ignored).
 #'
 #' @return An array of scores for each contrast and outcome.
@@ -234,6 +235,7 @@ get_scores.instrumental_forest <- function(forest,
 #' @export
 get_scores.multi_arm_causal_forest <- function(forest,
                                                subset = NULL,
+                                               drop = FALSE,
                                                ...) {
   subset <- validate_subset(forest, subset)
   W.orig <- forest$W.orig[subset]
@@ -260,7 +262,7 @@ get_scores.multi_arm_causal_forest <- function(forest,
   # using the subsetting syntax "matrix[index.matrix]".
   IPW <- matrix(0, length(subset), nlevels(W.orig))
   IPW[observed.treatment.idx] <- 1 / W.hat[observed.treatment.idx]
-  control <- IPW[, 1] != 0
+  control <- IPW[, 1] > 0
   IPW[control, -1] <- -1 * IPW[control, 1]
 
   IPW <- IPW[, -1, drop = FALSE]
@@ -281,7 +283,9 @@ get_scores.multi_arm_causal_forest <- function(forest,
 
   scores <- lapply(1:NCOL(forest$Y.orig), function(col) .get.scores(col))
 
-  array(unlist(scores), dim = c(length(subset), dim(forest.pp$predictions)[-1]), dimnames = dimnames(forest.pp$predictions))
+  array(unlist(scores),
+        dim = c(length(subset), dim(forest.pp$predictions)[-1]),
+        dimnames = dimnames(forest.pp$predictions))[, , , drop = drop]
 }
 
 #' Compute doubly robust scores for a causal survival forest.
@@ -293,6 +297,9 @@ get_scores.multi_arm_causal_forest <- function(forest,
 #'               estimate the ATE. WARNING: For valid statistical performance,
 #'               the subset should be defined only using features Xi, not using
 #'               the treatment Wi or the outcome Yi.
+#' @param num.trees.for.weights Number of trees used to estimate Var[W | X = x]. Note: this
+#'  argument is only used in the case of a continuous treatment
+#'  (see \code{\link{get_scores.causal_forest}} for details).
 #' @param ... Additional arguments (currently ignored).
 #'
 #' @return A vector of scores.
@@ -301,24 +308,43 @@ get_scores.multi_arm_causal_forest <- function(forest,
 #' @export
 get_scores.causal_survival_forest <- function(forest,
                                               subset = NULL,
+                                              num.trees.for.weights = 500,
                                               ...) {
   subset <- validate_subset(forest, subset)
-
-  if (min(forest$W.hat[subset]) <= 0.05 || max(forest$W.hat[subset]) >= 0.95) {
-    rng <- range(forest$W.hat[subset])
-    warning(paste0(
-      "Estimated treatment propensities take values very close to 0 or 1.",
-      " The estimated propensities are between ",
-      round(rng[1], 3), " and ", round(rng[2], 3),
-      ", meaning some estimates may not be well identified."
-    ))
-  }
-
   numerator <- forest[["_psi"]]$numerator[subset]
   denominator <- forest[["_psi"]]$denominator[subset]
-  W.hat <- forest$W.hat[subset]
   cate.hat <- predict(forest)$predictions[subset]
   psi <- numerator - denominator * cate.hat
 
-  cate.hat + psi * 1 / W.hat / (1 - W.hat)
+  binary.W <- all(forest$W.orig %in% c(0, 1))
+  if (binary.W) {
+    if (min(forest$W.hat[subset]) <= 0.05 || max(forest$W.hat[subset]) >= 0.95) {
+      rng <- range(forest$W.hat[subset])
+      warning(paste0(
+        "Estimated treatment propensities take values very close to 0 or 1.",
+        " The estimated propensities are between ",
+        round(rng[1], 3), " and ", round(rng[2], 3),
+        ", meaning some estimates may not be well identified."
+      ))
+    }
+    W.hat <- forest$W.hat[subset]
+    V.hat <- W.hat * (1 - W.hat)
+  } else {
+    # Estimate Var[W | X = x], as in get_scores.causal_forest.
+    clusters <- if (length(forest$clusters) > 0) {
+      forest$clusters
+    } else {
+      1:length(forest$Y.orig)
+    }
+    variance_forest <- regression_forest(forest$X.orig,
+                                         (forest$W.orig - forest$W.hat)^2,
+                                         clusters = clusters,
+                                         sample.weights = forest$sample.weights,
+                                         num.trees = num.trees.for.weights,
+                                         ci.group.size = 1,
+                                         seed = forest$seed)
+    V.hat <- predict(variance_forest)$predictions[subset]
+  }
+
+  cate.hat + psi / V.hat
 }
