@@ -55,9 +55,10 @@ ForestTrainer instrumental_trainer(double reduced_form_weight,
 
 ForestTrainer multi_causal_trainer(size_t num_treatments,
                                    size_t num_outcomes,
-                                   bool stabilize_splits) {
+                                   bool stabilize_splits,
+                                   const std::vector<double>& gradient_weights) {
   size_t response_length = num_treatments * num_outcomes;
-  std::unique_ptr<RelabelingStrategy> relabeling_strategy(new MultiCausalRelabelingStrategy(response_length));
+  std::unique_ptr<RelabelingStrategy> relabeling_strategy(new MultiCausalRelabelingStrategy(response_length, gradient_weights));
   std::unique_ptr<SplittingRuleFactory> splitting_rule_factory = stabilize_splits
     ? std::unique_ptr<SplittingRuleFactory>(new MultiCausalSplittingRuleFactory(response_length, num_treatments))
     : std::unique_ptr<SplittingRuleFactory>(new MultiRegressionSplittingRuleFactory(response_length));
